@@ -1,14 +1,8 @@
 #!/usr/bin/env python
 
-"""
-
-Copyright (C) 2020 Vanessa Sochat.
-
-This Source Code Form is subject to the terms of the
-Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
-with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
-"""
+__author__ = "Vanessa Sochat"
+__copyright__ = "Copyright 2020, Vanessa SOchat"
+__license__ = "MPL 2.0"
 
 from snakedeploy.logger import setup_logger
 from snakedeploy.providers import ProviderRunner
@@ -40,7 +34,7 @@ def get_parser():
 
     deploy_group = parser.add_argument_group("DEPLOY")
     deploy_group.add_argument(
-        "--remote",
+        "--create-remote",
         dest="template",
         help="Template the repository first to create a remote to clone. GITHUB_TOKEN is required.",
         default=False,
