@@ -1,12 +1,6 @@
-"""
-
-Copyright (C) 2020 Vanessa Sochat.
-
-This Source Code Form is subject to the terms of the
-Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
-with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
-"""
+__author__ = "Vanessa Sochat"
+__copyright__ = "Copyright 2020, Vanessa SOchat"
+__license__ = "MPL 2.0"
 
 
 class MissingEnvironmentVariable(RuntimeError):
